結果
| 問題 | No.397 NO MORE KADOMATSU |
| コンテスト | |
| ユーザー |
|
| 提出日時 | 2026-10-12 09:09:34 |
| 言語 | PyPy3 (7.3.23 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 170 ms / 2,000 ms |
| + 3µs | |
| コード長 | 305 bytes |
| 記録 | |
| コンパイル時間 | 63 ms |
| コンパイル使用メモリ | 82,172 KB |
| 実行使用メモリ | 75,600 KB |
| 平均クエリ数 | 936.56 |
| 最終ジャッジ日時 | 2026-10-12 09:09:37 |
| 合計ジャッジ時間 | 2,545 ms |
|
ジャッジサーバーID (参考情報) |
judge2_0 / judge4_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 18 |
ソースコード
N = int(input())
A = list(map(int, input().split()))
ans = []
for _ in range(N - 1):
for i in range(N - 1):
if A[i] > A[i + 1]:
A[i], A[i + 1] = A[i + 1], A[i]
ans.append((i, i + 1))
print(len(ans), flush=True)
for a in ans:
print(*a, flush=True)
D = int(input())